==> xlniuxdata-vipgame-1.0.6-20150327.020757-12-sources.jar: com/xunlei/niux/data/vipgame/bo/gift/GiftRecordBoImpl.java <==
package com.xunlei.niux.data.vipgame.bo.gift;

import java.util.List;
import java.util.Set;

import com.xunlei.niux.data.vipgame.dao.gift.GiftRecordDao;
import com.xunlei.niux.data.vipgame.dto.GiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.ProductDTO;

/**
 * Created by jamesjxin on 14-4-17.
 */
public class GiftRecordBoImpl implements GiftRecordBo{

    private GiftRecordDao giftRecordDao;

    public void setGiftRecordDao(final GiftRecordDao giftRecordDao) {
        this.giftRecordDao = giftRecordDao;
    }

    @Override
    public List<GiftRecordDTO> getUnReleaseProductGiftRecord() {
        return giftRecordDao.getUnReleaseProductGiftRecord();
    }

	@Override
	public List<ProductDTO> getBonusProductChargeList(final int max) {
		return giftRecordDao.getBonusProductChargeList(max);
	}

	@Override
	public List<?> getJiFenShopGiftRecord(final Class<?> object, final String userId, final int pageNo, final int pageSize) {
		return giftRecordDao.getJiFenShopGiftRecord(object, userId, pageNo, pageSize);
	}

    @Override
    public List<?> getUserGiftRecordByGiftType(Class<?> object, String userId,  Set<String> giftTypeParamSet, int pageNo, int pageSize) {
        return giftRecordDao.getUserGiftRecordByGiftType(object, userId,  giftTypeParamSet, pageNo, pageSize);
    }

    @Override
    public int countUserGiftRecordByGiftType(String userId, Set<String> giftTypeParamSet) {
        return giftRecordDao.countUserGiftRecordByGiftType(userId, giftTypeParamSet);
    }

    @Override
    public int coutJiFenShopGiftRecord(String userId) {
        return giftRecordDao.countJiFenShopGiftRecord(userId);
    }

}

==> xlniuxdata-vipgame-1.0.7-20150331.092636-2-sources.jar: com/xunlei/niux/data/vipgame/bo/gift/GiftRecordBoImpl.java <==
package com.xunlei.niux.data.vipgame.bo.gift;

import java.util.List;
import java.util.Set;

import com.xunlei.niux.data.vipgame.dao.gift.GiftRecordDao;
import com.xunlei.niux.data.vipgame.dto.GiftRecordDTO;
import com.xunlei.niux.data.vipgame.dto.ProductDTO;

/**
 * Created by jamesjxin on 14-4-17.
 */
public class GiftRecordBoImpl implements GiftRecordBo{

    private GiftRecordDao giftRecordDao;

    public void setGiftRecordDao(final GiftRecordDao giftRecordDao) {
        this.giftRecordDao = giftRecordDao;
    }

    @Override
    public List<GiftRecordDTO> getUnReleaseProductGiftRecord() {
        return giftRecordDao.getUnReleaseProductGiftRecord();
    }

	@Override
	public List<ProductDTO> getBonusProductChargeList(final int max) {
		return giftRecordDao.getBonusProductChargeList(max);
	}

	@Override
	public List<?> getJiFenShopGiftRecord(final Class<?> object, final String userId,  Set<String> giftTypeParamSet, final int pageNo, final int pageSize) {
		return giftRecordDao.getJiFenShopGiftRecord(object, userId,giftTypeParamSet, pageNo, pageSize);
	}

    @Override
    public List<?> getUserGiftRecordByGiftType(Class<?> object, String userId,  Set<String> giftTypeParamSet, int pageNo, int pageSize) {
        return giftRecordDao.getUserGiftRecordByGiftType(object, userId,  giftTypeParamSet, pageNo, pageSize);
    }

    @Override
    public int countUserGiftRecordByGiftType(String userId, Set<String> giftTypeParamSet) {
        return giftRecordDao.countUserGiftRecordByGiftType(userId, giftTypeParamSet);
    }

    @Override
    public int coutJiFenShopGiftRecord(String userId,  Set<String> giftTypeParamSet) {
        return giftRecordDao.countJiFenShopGiftRecord(userId, giftTypeParamSet);
    }

}
